@@ -7,7 +7,42 @@ from ..networkManager import *
 from ..seleneumManager import *
 from ..urlManager import *
 logging.basicConfig(level=logging.INFO)
+logging.basicConfig(level=logging.INFO)
+logger = logging.getLogger(__name__)
 
+# --- Cookie normalizer ---
+def normalize_cookies(cookies):
+    """
+    Normalize cookies into {name: str(value)} format.
+    Handles dicts, nested dicts, and RequestsCookieJar.
+    """
+    normalized = {}
+    if not cookies:
+        logger.debug("No cookies provided.")
+        return normalized
+
+    if isinstance(cookies, dict):
+        for k, v in cookies.items():
+            if isinstance(v, dict):
+                logger.warning(f"Cookie '{k}' is a dict, flattening with .get('value')")
+                v = v.get("value") or str(v)
+            if not isinstance(v, (str, bytes)):
+                logger.warning(f"Cookie '{k}' is {type(v)}, coercing: {v!r}")
+                v = str(v)
+            normalized[str(k)] = v
+
+    elif isinstance(cookies, requests.cookies.RequestsCookieJar):
+        for c in cookies:
+            v = c.value
+            if not isinstance(v, (str, bytes)):
+                logger.warning(f"Cookie '{c.name}' had non-string value {type(c.value)}, coercing: {v!r}")
+                v = str(v)
+            normalized[c.name] = v
+
+    else:
+        logger.error(f"Unexpected cookie container: {type(cookies)}")
+
+    return normalized
 class requestManager:
     """
     requestManager is a class for making HTTP requests with error handling and retries.
@@ -246,7 +281,7 @@ class requestManager:
         elif any([self.password, self.email, self.login_url, self.checkbox, self.dropdown]):
             s = self.authenticate(session=s, login_url=self.login_url, email=self.email, password=self.password, checkbox=self.checkbox, dropdown=self.dropdown)
         s.proxies = self.proxies
-        s.cookies["cf_clearance"] = self.network_manager.cookies
+ 
         s.headers.update(self.headers)
         s.mount(self.protocol, self.network_manager.tls_adapter)
         return s
