@@ -156,11 +156,12 @@ class VideoDownloader:
                 with yt_dlp.YoutubeDL(self._build_ydl_opts(tmp_outtmpl)) as ydl:
                     info = ydl.extract_info(video_url, download=self.get_download)
                     video_id = info.get("id") or generate_video_id(info.get("title") or "video")
-
-                    # --- Canonical base directory
-                    dirbase = os.path.join(self.download_directory, video_id)
+                    dirbase = self.download_directory
+                    if self.download_directory and os.path.isdir(self.download_directory) and not os.path.basename(self.download_directory) == video_id:
+                        # --- Canonical base directory
+                        dirbase = os.path.join(self.download_directory, video_id)
                     os.makedirs(dirbase, exist_ok=True)
-
+                    
                     # --- Final video file
                     temp_path = ydl.prepare_filename(info)
                     _, ext = os.path.splitext(temp_path)
